@@ -1,18 +1,18 @@
 package File::Slurper::Temp;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-02'; # DATE
-our $DIST = 'File-Slurper-Temp'; # DIST
-our $VERSION = '0.008'; # VERSION
-
 use strict;
 use warnings;
 
 use Carp 'croak', 'carp';
+use Exporter qw(import);
 use File::Slurper ();
 use File::Temp ();
 
-use Exporter qw(import);
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-06-17'; # DATE
+our $DIST = 'File-Slurper-Temp'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 our @EXPORT_OK = qw(
                        write_text write_binary
                        write_text_to_tempfile write_binary_to_tempfile
@@ -109,7 +109,7 @@ File::Slurper::Temp - File::Slurper + File::Temp
 
 =head1 VERSION
 
-This document describes version 0.008 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2021-08-02.
+This document describes version 0.009 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2024-06-17.
 
 =head1 SYNOPSIS
 
@@ -151,11 +151,11 @@ return the temporary filename created.
 
 =head1 VARIABLES
 
-=head2 $FILE_PERM_DIR
+=head2 $FILE_TEMP_DIR
 
-=head2 $FILE_PERM_PERMS
+=head2 $FILE_TEMP_PERMS
 
-=head2 $FILE_PERM_TEMPLATE
+=head2 $FILE_TEMP_TEMPLATE
 
 =head1 FUNCTIONS
 
@@ -226,14 +226,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Slurp
 
 Source repository is at L<https://github.com/perlancar/perl-File-Slurper-Temp>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Slurper-Temp>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<File::Slurper>
@@ -246,11 +238,43 @@ C<modify_text()> and C<modify_binary()> follows L<File::Slurper::Shortcuts>.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords George Baugh
+
+George Baugh <george@troglodyne.net>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2019, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2019, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Slurper-Temp>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
